@@ -2,7 +2,7 @@ from bigxml.utils import extract_namespace_name
 
 
 def test_no_namespace():
-    assert extract_namespace_name("foo") == (None, "foo")
+    assert extract_namespace_name("foo") == ("", "foo")
 
 
 def test_namespace():
@@ -13,4 +13,4 @@ def test_namespace():
 
 
 def test_empty_namespace():
-    assert extract_namespace_name(r"{}foo") == ("", "foo",)
+    assert extract_namespace_name(r"{}foo") == ("", "foo")
